@@ -10,22 +10,21 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.identity import identity_service
-from openstack import resource2 as resource
+from openstack import resource
 
 
 class Role(resource.Resource):
     resource_key = 'role'
     resources_key = 'roles'
     base_path = '/roles'
-    service = identity_service.IdentityService()
 
     # capabilities
     allow_create = True
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
+    commit_method = 'PATCH'
 
     _query_mapping = resource.QueryParameters(
         'name', 'domain_id')
@@ -33,5 +32,9 @@ class Role(resource.Resource):
     # Properties
     #: Unique role name, within the owning domain. *Type: string*
     name = resource.Body('name')
+    #: User-facing description of the role. *Type: string*
+    description = resource.Body('description')
+    #: References the domain ID which owns the role. *Type: string*
+    domain_id = resource.Body('domain_id')
     #: The links for the service resource.
     links = resource.Body('links')
