@@ -23,3 +23,11 @@ class BaseBlockStorageTest(base.BaseFunctionalTest):
         cls._wait_for_timeout = int(os.getenv(
             'OPENSTACKSDK_FUNC_TEST_TIMEOUT_BLOCK_STORAGE',
             cls._wait_for_timeout))
+
+    def setUp(self):
+        super(BaseBlockStorageTest, self).setUp()
+        self._set_user_cloud(block_storage_api_version='2')
+        self._set_operator_cloud(block_storage_api_version='2')
+
+        if not self.user_cloud.has_service('block-storage'):
+            self.skipTest('block-storage service not supported by cloud')
