@@ -16,6 +16,8 @@ from openstack import exceptions
 from openstack.image.v2 import _proxy
 from openstack.image.v2 import image
 from openstack.image.v2 import member
+from openstack.image.v2 import schema
+from openstack.image.v2 import task
 from openstack.tests.unit.image.v2 import test_image as fake_image
 from openstack.tests.unit import test_proxy_base
 
@@ -27,11 +29,26 @@ class TestImageProxy(test_proxy_base.TestProxyBase):
         super(TestImageProxy, self).setUp()
         self.proxy = _proxy.Proxy(self.session)
 
-    def test_image_create_no_args(self):
+    def test_image_import_no_required_attrs(self):
+        # container_format and disk_format are required attrs of the image
+        existing_image = image.Image(id="id")
+        self.assertRaises(exceptions.InvalidRequest,
+                          self.proxy.import_image,
+                          existing_image)
+
+    def test_image_import(self):
+        original_image = image.Image(**EXAMPLE)
+        self._verify("openstack.image.v2.image.Image.import_image",
+                     self.proxy.import_image,
+                     method_args=[original_image, "method", "uri"],
+                     expected_kwargs={"method": "method",
+                                      "uri": "uri"})
+
+    def test_image_upload_no_args(self):
         # container_format and disk_format are required args
         self.assertRaises(exceptions.InvalidRequest, self.proxy.upload_image)
 
-    def test_image_create(self):
+    def test_image_upload(self):
         # NOTE: This doesn't use any of the base class verify methods
         # because it ends up making two separate calls to complete the
         # operation.
@@ -74,7 +91,7 @@ class TestImageProxy(test_proxy_base.TestProxyBase):
         self.verify_get(self.proxy.get_image, image.Image)
 
     def test_images(self):
-        self.verify_list(self.proxy.images, image.Image, paginated=True)
+        self.verify_list(self.proxy.images, image.Image)
 
     def test_add_tag(self):
         self._verify("openstack.image.v2.image.Image.add_tag",
@@ -151,6 +168,64 @@ class TestImageProxy(test_proxy_base.TestProxyBase):
                                        'image_id': 'image_id'})
 
     def test_members(self):
-        self.verify_list(self.proxy.members, member.Member, paginated=False,
+        self.verify_list(self.proxy.members, member.Member,
                          method_args=('image_1',),
                          expected_kwargs={'image_id': 'image_1'})
+
+    def test_images_schema_get(self):
+        self._verify2("openstack.proxy.Proxy._get",
+                      self.proxy.get_images_schema,
+                      expected_args=[schema.Schema],
+                      expected_kwargs={'base_path': '/schemas/images',
+                                       'requires_id': False})
+
+    def test_image_schema_get(self):
+        self._verify2("openstack.proxy.Proxy._get",
+                      self.proxy.get_image_schema,
+                      expected_args=[schema.Schema],
+                      expected_kwargs={'base_path': '/schemas/image',
+                                       'requires_id': False})
+
+    def test_members_schema_get(self):
+        self._verify2("openstack.proxy.Proxy._get",
+                      self.proxy.get_members_schema,
+                      expected_args=[schema.Schema],
+                      expected_kwargs={'base_path': '/schemas/members',
+                                       'requires_id': False})
+
+    def test_member_schema_get(self):
+        self._verify2("openstack.proxy.Proxy._get",
+                      self.proxy.get_member_schema,
+                      expected_args=[schema.Schema],
+                      expected_kwargs={'base_path': '/schemas/member',
+                                       'requires_id': False})
+
+    def test_task_get(self):
+        self.verify_get(self.proxy.get_task, task.Task)
+
+    def test_tasks(self):
+        self.verify_list(self.proxy.tasks, task.Task)
+
+    def test_task_create(self):
+        self.verify_create(self.proxy.create_task, task.Task)
+
+    def test_task_wait_for(self):
+        value = task.Task(id='1234')
+        self.verify_wait_for_status(
+            self.proxy.wait_for_task,
+            method_args=[value],
+            expected_args=[value, 'success', ['failure'], 2, 120])
+
+    def test_tasks_schema_get(self):
+        self._verify2("openstack.proxy.Proxy._get",
+                      self.proxy.get_tasks_schema,
+                      expected_args=[schema.Schema],
+                      expected_kwargs={'base_path': '/schemas/tasks',
+                                       'requires_id': False})
+
+    def test_task_schema_get(self):
+        self._verify2("openstack.proxy.Proxy._get",
+                      self.proxy.get_task_schema,
+                      expected_args=[schema.Schema],
+                      expected_kwargs={'base_path': '/schemas/task',
+                                       'requires_id': False})
