@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
+from openstack.tests.unit import base
 
 from openstack.network.v2 import security_group_rule
 
@@ -33,17 +33,16 @@ EXAMPLE = {
 }
 
 
-class TestSecurityGroupRule(testtools.TestCase):
+class TestSecurityGroupRule(base.TestCase):
 
     def test_basic(self):
         sot = security_group_rule.SecurityGroupRule()
         self.assertEqual('security_group_rule', sot.resource_key)
         self.assertEqual('security_group_rules', sot.resources_key)
         self.assertEqual('/security-group-rules', sot.base_path)
-        self.assertEqual('network', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertFalse(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertFalse(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
